/* File: xmi_element_part.c; Copyright and License: see below */

#include "xmi/xmi_element_part.h"

/* constants naming scheme: XMI_ELEMENT_PART_<XMI-CONTEXT>_<LITERAL> */

const char * const XMI_ELEMENT_PART_FALLBACK_NESTING_ELEMENT
    = "packagedElement";

const char * const XMI_ELEMENT_PART_ELEMENT_OWNED_END
    = "ownedEnd";

const char * const XMI_ELEMENT_PART_TYPE_PROPERTY
    = "Property";

const char * const XMI_ELEMENT_PART_ID_FRAGMENT_SOURCE_END
    = "#sourceend";

const char * const XMI_ELEMENT_PART_ID_FRAGMENT_TARGET_END
    = "#targetend";

const char * const XMI_ELEMENT_PART_PROPERTY_ASSOCIATION_ATTRIBUTE
    = "association";
    
const char * const XMI_ELEMENT_PART_PROPERTY_TYPE_ELEMENT
    = "type";

const char * const XMI_ELEMENT_PART_PROPERTY_CLASS_ELEMENT
    = "class";

const char * const XMI_ELEMENT_PART_PROPERTY_INTERFACE_ELEMENT
    = "interface";

const char * const XMI_ELEMENT_PART_PROPERTY_AGGREGATION_ATTRIBUTE
    = "aggregation";

const char * const XMI_ELEMENT_PART_PROPERTY_AGGREGATION_SHARED
    = "shared";

const char * const XMI_ELEMENT_PART_PROPERTY_AGGREGATION_COMPOSITE
    = "composite";

const char * const XMI_ELEMENT_PART_TYPE_MSG_OCCURRENCE_SPEC
    = "MessageOccurrenceSpecification";

const char * const XMI_ELEMENT_PART_PROPERTY_OCCURRENCE_SPEC_COVERED
    = "covered";


/*
Copyright 2020-2020 Andreas Warnke

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/
